@@ -54,7 +54,11 @@ class abook_group_database {
 
     /* Constructor */
     function abook_group_database($param) {
+        bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+        textdomain('abook_group');
         $this->sname = _("Global address book");
+        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+        textdomain('squirrelmail');
 
         if (is_array($param)) {
             if (empty($param['dsn']) ||
@@ -100,8 +104,12 @@ class abook_group_database {
         $dbh = DB::connect($this->dsn, true);
 
         if (DB::isError($dbh)) {
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
             return $this->set_error(sprintf(_("Database error: %s"),
                                             DB::errorMessage($dbh)));
+            bindtextdomain('squirrelmail', SM_PATH . 'locale');
+            textdomain('squirrelmail');
         }
 
         $this->dbh = $dbh;
@@ -128,8 +136,12 @@ class abook_group_database {
         $res = $this->dbh->query($query);
 
         if (DB::isError($res)) {
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
             return $this->set_error(sprintf(_("Database error: %s"),
                                             DB::errorMessage($res)));
+            bindtextdomain('squirrelmail', SM_PATH . 'locale');
+            textdomain('squirrelmail');
         }
 
         while ($row = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
@@ -156,12 +168,27 @@ class abook_group_database {
                 }else{
                     $ownerClause = "";
                 }
-                $query = sprintf("SELECT b.nickname,b.firstname,b.lastname,b.email FROM %s a, %s b WHERE a.owner='%s' %s AND a.nickname=b.nickname AND a.addressgroup ='%s' AND a.type='%s' ORDER BY a.nickname asc",$this->table, $abook->backends[$bnum]->table,$this->owner, $ownerClause,$group,$abook->backends[$bnum]->sname);
+                /* Added for il8n */
+                $thisTable = $this->table;
+                $abookBackendsTable = $abook->backends[$bnum]->table;
+                $thisOwner = $this->owner;
+                $abookBackendsSname = $abook->backends[$bnum]->sname;
+                $thisTable = addslashes ($thisTable);
+                $abookBackendsTable = addslashes ($abookBackendsTable);
+                $thisOwner = addslashes ($thisOwner);
+                $ownerClause = addslashes ($ownerClause);
+                $group = addslashes ($group);
+                $abookBackendsSname = addslashes ($abookBackendsSname);
 
+                $query = sprintf("SELECT b.nickname,b.firstname,b.lastname,b.email FROM %s a, %s b WHERE a.owner='%s' %s AND a.nickname=b.nickname AND a.addressgroup ='%s' AND a.type='%s' ORDER BY a.nickname asc",$thisTable, $abookBackendsTable,$thisOwner,$ownerClause,$group,$abookBackendsSname);
                 $res = $this->dbh->query($query);
 
                 if (DB::isError($res)) {
+                   bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+                   textdomain('abook_group');
                    return $this->set_error(sprintf(_("Database error: %s"), DB::errorMessage($res)));
+                   bindtextdomain('squirrelmail', SM_PATH . 'locale');
+                   textdomain('squirrelmail');
                 }
 
                 while ($row = $res->fetchRow(DB_FETCHMODE_ASSOC)) {
@@ -182,7 +209,13 @@ class abook_group_database {
     function addToGroup($arrayOfUsers, $groupName, $new=false) {
 
         if (!$this->writeable) {
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
+
             return $this->set_error(_("Addressbook is read-only"));
+
+            bindtextdomain('squirrelmail', SM_PATH . 'locale');
+            textdomain('squirrelmail');
         }
 
         if (!$this->open()) {
@@ -198,7 +231,11 @@ class abook_group_database {
                    array_push($ret, array('addressgroup' => $row['addressgroup']));
                 }
                 if (!empty($ret)) {
-                   return $this->error = "Group $groupName already exist";
+                   bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+                   textdomain('abook_group');
+                   return $this->error = _("Group $groupName already exists");
+                   bindtextdomain('squirrelmail', SM_PATH . 'locale');
+                   textdomain('squirrelmail');
                 }
         }
 
@@ -213,14 +250,26 @@ class abook_group_database {
     /* Add New User into Group */
     function addUser($nickName, $groupName, $owner, $type) {
         //* See if GROUP exist already /
-        $query = sprintf("SELECT distinct(nickname) FROM %s WHERE owner='%s'AND addressgroup='%s' AND type='%s' AND nickname='%s'", $this->table, $owner, $groupName,$type,$nickName);
+        $type = addslashes ($type);
+        $nickName = addslashes ($nickName);
+        $groupName = addslashes ($groupName);
+        $owner = addslashes ($owner);
+        $query = sprintf ("SELECT distinct(nickname) FROM %s WHERE owner='%s'AND addressgroup='%s' AND type='%s' AND nickname='%s'", $this->table, $owner, $groupName,$type,$nickName);
+        $type = stripslashes ($type);
+        $nickName = stripslashes ($nickName);
+        $groupName = stripslashes ($groupName);
+        $owner = stripslashes ($owner);
         $res = $this->dbh->query($query);
         $ret = array();
         if ($row = $res->fetchRow(DB_FETCHMODE_ORDERED)) {
            array_push($ret, array('nickname' => $row[0]));
         }
         if (!empty($ret)) {
-           return $this->error = "User Already Exists in The Group";
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+           return $this->error = _("User Already Exists in The Group");
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
 
         //* Create query /
@@ -237,8 +286,12 @@ class abook_group_database {
          }
 
          //* Fail /
+         bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+         textdomain('abook_group');
          return $this->set_error(sprintf(_("Database error: %s"),
                                          DB::errorMessage($r)));
+         bindtextdomain('squirrelmail', SM_PATH . 'locale');
+         textdomain('squirrelmail');
     }
     
     function set_error($string) {
@@ -250,7 +303,11 @@ class abook_group_database {
     function removeFromGroup($arrayOfUsers, $groupName) {
 
         if (!$this->writeable) {
+         bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+         textdomain('abook_group');
             return $this->set_error(_("Addressbook is read-only"));
+         bindtextdomain('squirrelmail', SM_PATH . 'locale');
+         textdomain('squirrelmail');
         }
 
         if (!$this->open()) {
@@ -276,7 +333,11 @@ class abook_group_database {
            array_push($ret, array('nickname' => $row[0]));
         }
         if (empty($ret)) {
-           return $this->error = "User Does Not Exist in The Group";
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+           return $this->error = _("User Does Not Exist in The Group");
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
 
         //* Create query /
@@ -293,15 +354,23 @@ class abook_group_database {
          }
 
          //* Fail /
+         bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+         textdomain('abook_group');
          return $this->set_error(sprintf(_("Database error: %s"),
                                          DB::errorMessage($r)));
+         bindtextdomain('squirrelmail', SM_PATH . 'locale');
+         textdomain('squirrelmail');
     }
     
     /* Remove Group */
     function deleteGroup($groupName) {
 
         if (!$this->writeable) {
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
             return $this->set_error(_("Addressbook is read-only"));
+            bindtextdomain('squirrelmail', SM_PATH . 'locale');
+            textdomain('squirrelmail');
         }
 
         if (!$this->open()) {
@@ -316,7 +385,11 @@ class abook_group_database {
            array_push($ret, array('addressgroup' => $row['addressgroup']));
         }
         if (empty($ret)) {
-           return $this->error = "$groupName does not exist";
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+           return $this->error = _("$groupName does not exist");
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
         
         //* Create query /
@@ -331,15 +404,23 @@ class abook_group_database {
          }
 
          //* Fail /
+         bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+         textdomain('abook_group');
          return $this->set_error(sprintf(_("Database error: %s"),
                                          DB::errorMessage($r)));
+         bindtextdomain('squirrelmail', SM_PATH . 'locale');
+         textdomain('squirrelmail');
 
     }
 
     /* Modify address group*/
     function modifyGroup($groupName, $newGroupName) {
         if (!$this->writeable) {
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
             return $this->set_error(_("Addressbook is read-only"));
+            bindtextdomain('squirrelmail', SM_PATH . 'locale');
+            textdomain('squirrelmail');
         }
 
         if (!$this->open()) {
@@ -354,7 +435,11 @@ class abook_group_database {
            array_push($ret, array('addressgroup' => $row['addressgroup']));
         }
         if (empty($ret)) {
-           return $this->error = "$groupName does not exist";
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+           return $this->error = _("$groupName does not exist");
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
 
         //* See if another GROUP with same name exist already /
@@ -365,7 +450,11 @@ class abook_group_database {
            array_push($ret, array('addressgroup' => $row['addressgroup']));
         }
         if (!empty($ret)) {
-           return $this->error = "Another $newGroupName already exists";
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+           return $this->error = _("Another $newGroupName already exists");
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
 
         //* Create query /
@@ -380,8 +469,12 @@ class abook_group_database {
         }
 
         //* Fail /
+        bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+        textdomain('abook_group');
         return $this->set_error(sprintf(_("Database error: %s"),
                                         DB::errorMessage($r)));
+        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+        textdomain('squirrelmail');
     }
 
 } /* End of class abook_group_database */
