@@ -8,6 +8,7 @@
     **
     **  This is a standard Squirrelmail-1.2 API for plugins.
     **/
+    include_once(SM_PATH . 'functions/i18n.php');
 
     function squirrelmail_plugin_init_abook_group() {
         /* Standard initialization API. */
@@ -22,7 +23,7 @@
     }
 
     function abook_group_version() {
-       return '0.21';
+       return '0.32';
     }
 
 
@@ -32,6 +33,9 @@
 
        if ( !soupNazi() ) {
 
+           bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+           textdomain('abook_group');
+
            /* Register abook_group with the $optionpages array. */
            $optpage_blocks[] = array(
                'name' => _("Address Groups"),
@@ -39,6 +43,9 @@
                'desc' => _("You can create address groups and add email addresses from your address book"),
                'js'   => FALSE
             );
+
+           bindtextdomain('squirrelmail', SM_PATH . 'locale');
+           textdomain('squirrelmail');
         }
     }
 
@@ -50,13 +57,16 @@
             ** using document.write to hide this functionality from people
             ** with JavaScript turned off.        
             */
+            bindtextdomain('abook_group', SM_PATH . 'plugins/abook_group/locale');
+            textdomain('abook_group');
             echo "<script type=\"text/javascript\">\n".
                     "<!--\n".
                     'document.write("<input type=\"button\" value=\"' .
                         _("Groups") . '\" onclick=\"window.open(\'../plugins/abook_group/abook_group_interface.php\', \'abookgroup\', \'status=yes,width=550,height=370,resizable=yes,scrollbars=yes\')\">");'. "\n" .
                     "//-->\n".
                     "</script>\n";
+                    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+                    textdomain('squirrelmail');
         }
     }
-
 ?>
